@@ -3,6 +3,7 @@ import pandas as pd
 from rdkit import Chem, DataStructs
 from rdkit.Chem import AllChem
 from rdkit.Chem.Fingerprints import FingerprintMols
+from rdkit.Chem.rdReducedGraphs import GetErGFingerprint
 from DeepPurpose.pybiomed_helper import _GetPseudoAAC, CalculateAADipeptideComposition, \
 calcPubChemFingerAll, CalculateConjointTriad, GetQuasiSequenceOrder
 import torch
@@ -24,8 +25,8 @@ import pathlib
 
 this_dir = str(pathlib.Path(__file__).parent.absolute())
 
-MAX_ATOM = 200
-MAX_BOND = 400
+MAX_ATOM = 400
+MAX_BOND = MAX_ATOM * 2
 
 # ESPF encoding
 vocab_path = f"{this_dir}/ESPF/drug_codes_chembl_freq_1500.txt"
@@ -118,6 +119,15 @@ def index_select_ND(source, dim, index):
     target = source.index_select(dim, index.view(-1))
     return target.view(final_size)
 
+def smiles2erg(s):
+    try:
+        mol = Chem.MolFromSmiles(s)
+        features = np.array(GetErGFingerprint(mol))
+    except:
+        print('rdkit cannot find this SMILES for ErG: ' + s + 'convert to all 0 features')
+        features = np.zeros((315, ))
+    return features
+
 def smiles2morgan(s, radius = 2, nBits = 1024):
     try:
         mol = Chem.MolFromSmiles(s)
@@ -266,7 +276,7 @@ def smiles2mpnnfeature(smiles):
 	try:
 		assert atoms_completion_num >= 0 and bonds_completion_num >= 0
 	except:
-		raise Exception("Please increasing MAX_ATOM and MAX_BOND in line 24,25 utils.py and reinstall it. The current setting is for small molecule. ")
+		raise Exception("Please increasing MAX_ATOM in line 26 utils.py, for example, MAX_ATOM=600 and reinstall it via 'python setup.py install'. The current setting is for small molecule. ")
 
 
 	fatoms_dim = fatoms.shape[1]
@@ -367,6 +377,10 @@ def encode_drug(df_data, drug_encoding, column_name = 'SMILES', save_column_name
 		unique = pd.Series(df_data[column_name].unique()).apply(smiles2mpnnfeature)
 		unique_dict = dict(zip(df_data[column_name].unique(), unique))
 		df_data[save_column_name] = [unique_dict[i] for i in df_data[column_name]]
+	elif drug_encoding == 'ErG':
+		unique = pd.Series(df_data[column_name].unique()).apply(smiles2erg)
+		unique_dict = dict(zip(df_data[column_name].unique(), unique))
+		df_data[save_column_name] = [unique_dict[i] for i in df_data[column_name]]
 	else:
 		raise AttributeError("Please use the correct drug encoding available!")
 	return df_data
@@ -395,9 +409,9 @@ def encode_protein(df_data, target_encoding, column_name = 'Target Sequence', sa
 		AA_dict = dict(zip(df_data[column_name].unique(), AA))
 		df_data[save_column_name] = [AA_dict[i] for i in df_data[column_name]]
 	elif target_encoding == 'ESPF':
-		unique = pd.Series(df_data[column_name].unique()).apply(protein2espf)
-		unique_dict = dict(zip(df_data[column_name].unique(), unique))
-		df_data[save_column_name] = [unique_dict[i] for i in df_data[column_name]]
+		AA = pd.Series(df_data[column_name].unique()).apply(protein2espf)
+		AA_dict = dict(zip(df_data[column_name].unique(), AA))
+		df_data[save_column_name] = [AA_dict[i] for i in df_data[column_name]]
 	elif target_encoding == 'CNN':
 		AA = pd.Series(df_data[column_name].unique()).apply(trans_protein)
 		AA_dict = dict(zip(df_data[column_name].unique(), AA))
@@ -768,6 +782,9 @@ def generate_config(drug_encoding = None, target_encoding = None,
 	
 	if drug_encoding == 'Morgan':
 		base_config['mlp_hidden_dims_drug'] = mlp_hidden_dims_drug # MLP classifier dim 1				
+	elif drug_encoding == 'ErG':
+		base_config['input_dim_drug'] = 315
+		base_config['mlp_hidden_dims_drug'] = mlp_hidden_dims_drug # MLP classifier dim 1
 	elif drug_encoding == 'Pubchem':
 		base_config['input_dim_drug'] = 881
 		base_config['mlp_hidden_dims_drug'] = mlp_hidden_dims_drug # MLP classifier dim 1				
@@ -980,11 +997,11 @@ def drug_2_embed(x):
 	return enc_drug.transform(np.array(x).reshape(-1,1)).toarray().T    
 
 def save_dict(path, obj):
-	with open(path + '/config.pkl', 'wb') as f:
+	with open(os.path.join(path, 'config.pkl'), 'wb') as f:
 		pickle.dump(obj, f, pickle.HIGHEST_PROTOCOL)
 
 def load_dict(path):
-	with open(path + '/config.pkl', 'rb') as f:
+	with open(os.path.join(path, 'config.pkl'), 'rb') as f:
 		return pickle.load(f)
 
 URLs = {
@@ -1288,10 +1305,10 @@ def download_pretrained_model(model_name, save_dir = './save_folder'):
 
 	if not os.path.exists(save_dir):
 		os.mkdir(save_dir)
-	if not os.path.exists(os.path.join(save_dir, 'pretrained_model')):
-		os.mkdir(os.path.join(save_dir, 'pretrained_model'))
+	if not os.path.exists(os.path.join(save_dir, 'pretrained_models')):
+		os.mkdir(os.path.join(save_dir, 'pretrained_models'))
 
-	pretrained_dir = os.path.join(save_dir, 'pretrained_model')
+	pretrained_dir = os.path.join(save_dir, 'pretrained_models')
 	downloaded_path = os.path.join(pretrained_dir, name2zipfilename[model_name.lower()] + '.zip')
 
 	if os.path.exists(os.path.join(pretrained_dir, name2filename[model_name.lower()])):
